@@ -32,7 +32,6 @@
 #include <gdk/gdkkeysyms.h>
 
 #include <pluma/pluma-utils.h>
-#include <pluma/pluma-plugin.h>
 
 #include "pluma-file-browser-utils.h"
 #include "pluma-file-browser-error.h"
@@ -50,10 +49,6 @@
 #define XML_UI_FILE "pluma-file-browser-widget-ui.xml"
 #define LOCATION_DATA_KEY "pluma-file-browser-widget-location"
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
-#endif
-
 enum 
 {
 	BOOKMARKS_ID,
@@ -240,13 +235,8 @@ static void on_action_filter_binary            (GtkAction * action,
 static void on_action_bookmark_open            (GtkAction * action,
 						PlumaFileBrowserWidget * obj);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-PLUMA_PLUGIN_DEFINE_TYPE (PlumaFileBrowserWidget, pluma_file_browser_widget,
+G_DEFINE_DYNAMIC_TYPE (PlumaFileBrowserWidget, pluma_file_browser_widget,
 	                  GTK_TYPE_BOX)
-#else
-PLUMA_PLUGIN_DEFINE_TYPE (PlumaFileBrowserWidget, pluma_file_browser_widget,
-	                  GTK_TYPE_VBOX)
-#endif
 
 static void
 free_name_icon (gpointer data)
@@ -369,11 +359,7 @@ pluma_file_browser_widget_finalize (GObject * object)
 	
 	cancel_async_operation (obj);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	g_object_unref (obj->priv->busy_cursor);
-#else
-	gdk_cursor_unref (obj->priv->busy_cursor);
-#endif
 
 	G_OBJECT_CLASS (pluma_file_browser_widget_parent_class)->finalize (object);
 }
@@ -492,6 +478,12 @@ pluma_file_browser_widget_class_init (PlumaFileBrowserWidgetClass * klass)
 				  sizeof (PlumaFileBrowserWidgetPrivate));
 }
 
+static void
+pluma_file_browser_widget_class_finalize (PlumaFileBrowserWidgetClass *klass)
+{
+	/* dummy function - used by G_DEFINE_DYNAMIC_TYPE */
+}
+
 static void
 add_signal (PlumaFileBrowserWidget * obj, gpointer object, gulong id)
 {
@@ -1237,7 +1229,7 @@ create_filter (PlumaFileBrowserWidget * obj)
 	gtk_widget_show (expander);
 	gtk_box_pack_start (GTK_BOX (obj), expander, FALSE, FALSE, 0);
 
-	vbox = gtk_vbox_new (FALSE, 3);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
 	gtk_widget_show (vbox);
 
 	obj->priv->filter_expander = expander;
@@ -1261,9 +1253,8 @@ create_filter (PlumaFileBrowserWidget * obj)
 static void
 pluma_file_browser_widget_init (PlumaFileBrowserWidget * obj)
 {
-#if GTK_CHECK_VERSION (3, 16, 0)
 	GdkDisplay *display;
-#endif
+
 	obj->priv = PLUMA_FILE_BROWSER_WIDGET_GET_PRIVATE (obj);
 
 	obj->priv->bookmarks_hash = g_hash_table_new_full (g_file_hash,
@@ -1272,17 +1263,11 @@ pluma_file_browser_widget_init (PlumaFileBrowserWidget * obj)
 			                                   free_name_icon);
 
 	gtk_box_set_spacing (GTK_BOX (obj), 3);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (obj),
 	                                GTK_ORIENTATION_VERTICAL);
-#endif
 	
-#if GTK_CHECK_VERSION (3, 16, 0)
 	display = gtk_widget_get_display (GTK_WIDGET (obj));
 	obj->priv->busy_cursor = gdk_cursor_new_for_display (display, GDK_WATCH);
-#else
-	obj->priv->busy_cursor = gdk_cursor_new (GDK_WATCH);
-#endif
 }
 
 /* Private */
@@ -2122,23 +2107,13 @@ set_busy (PlumaFileBrowserWidget *obj, gboolean busy)
 
 	if (busy)
 	{
-#if GTK_CHECK_VERSION (3, 16, 0)
 		GdkDisplay *display;
 		GdkCursor *cursor;
 
 		display = gtk_widget_get_display (GTK_WIDGET (obj));
 		cursor = gdk_cursor_new_for_display (display, GDK_WATCH);
-#else
-		GdkCursor *cursor;
-
-		cursor = gdk_cursor_new (GDK_WATCH);
-#endif
 		gdk_window_set_cursor (window, cursor);
-#if GTK_CHECK_VERSION (3, 0, 0)
 		g_object_unref (obj->priv->busy_cursor);
-#else
-		gdk_cursor_unref (cursor);
-#endif
 	}
 	else
 	{
@@ -3182,4 +3157,10 @@ on_action_bookmark_open (GtkAction * action, PlumaFileBrowserWidget * obj)
 		bookmark_open (obj, model, &iter);
 }
 
+void
+_pluma_file_browser_widget_register_type (GTypeModule *type_module)
+{
+	pluma_file_browser_widget_register_type (type_module);
+}
+
 // ex:ts=8:noet:
