@@ -109,11 +109,7 @@ static guint signals [LAST_SIGNAL] = { 0 };
 G_DEFINE_TYPE(PlumaSpellCheckerDialog, pluma_spell_checker_dialog, GTK_TYPE_WINDOW)
 
 static void
-#if GTK_CHECK_VERSION (3, 0,0)
 pluma_spell_checker_dialog_dispose (GObject *object)
-#else
-pluma_spell_checker_dialog_destroy (GtkObject *object)
-#endif
 {
 	PlumaSpellCheckerDialog *dlg = PLUMA_SPELL_CHECKER_DIALOG (object);
 
@@ -129,11 +125,7 @@ pluma_spell_checker_dialog_destroy (GtkObject *object)
 		dlg->misspelled_word = NULL;
 	}
 
-#if GTK_CHECK_VERSION (3, 0,0)
 	G_OBJECT_CLASS (pluma_spell_checker_dialog_parent_class)->dispose (object);
-#else
-	GTK_OBJECT_CLASS (pluma_spell_checker_dialog_parent_class)->destroy (object);
-#endif
 }
 
 static void
@@ -143,11 +135,7 @@ pluma_spell_checker_dialog_class_init (PlumaSpellCheckerDialogClass * klass)
 
 	object_class = G_OBJECT_CLASS (klass);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	object_class->dispose = pluma_spell_checker_dialog_dispose;
-#else
-	GTK_OBJECT_CLASS (object_class)->destroy = pluma_spell_checker_dialog_destroy;
-#endif
 
 	signals[IGNORE] = 
 		g_signal_new ("ignore",
@@ -303,11 +291,7 @@ create_dialog (PlumaSpellCheckerDialog *dlg,
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
 	/* Set default button */
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_set_can_default (dlg->change_button, TRUE);
-#else
-	GTK_WIDGET_SET_FLAGS (dlg->change_button, GTK_CAN_DEFAULT);
-#endif
 	gtk_widget_grab_default (dlg->change_button);
 
 	gtk_entry_set_activates_default (GTK_ENTRY (dlg->word_entry), TRUE);
@@ -652,15 +636,17 @@ ignore_all_button_clicked_handler (GtkButton *button, PlumaSpellCheckerDialog *d
 static void
 change_button_clicked_handler (GtkButton *button, PlumaSpellCheckerDialog *dlg)
 {
-	gchar *word;
+	const gchar *entry_text;
 	gchar *change;
+	gchar *word;
 
 	g_return_if_fail (PLUMA_IS_SPELL_CHECKER_DIALOG (dlg));
 	g_return_if_fail (dlg->misspelled_word != NULL);
 
-	change = g_strdup (gtk_entry_get_text (GTK_ENTRY (dlg->word_entry)));
-	g_return_if_fail (change != NULL);
-	g_return_if_fail (*change != '\0');
+	entry_text = gtk_entry_get_text (GTK_ENTRY (dlg->word_entry));
+	g_return_if_fail (entry_text != NULL);
+	g_return_if_fail (*entry_text != '\0');
+	change = g_strdup (entry_text);
 
 	pluma_spell_checker_set_correction (dlg->spell_checker, 
 					    dlg->misspelled_word, -1, 
@@ -689,15 +675,17 @@ suggestions_list_row_activated_handler (GtkTreeView *view,
 static void
 change_all_button_clicked_handler (GtkButton *button, PlumaSpellCheckerDialog *dlg)
 {
-	gchar *word;
+	const gchar *entry_text;
 	gchar *change;
+	gchar *word;
 		
 	g_return_if_fail (PLUMA_IS_SPELL_CHECKER_DIALOG (dlg));
 	g_return_if_fail (dlg->misspelled_word != NULL);
 
-	change = g_strdup (gtk_entry_get_text (GTK_ENTRY (dlg->word_entry)));
-	g_return_if_fail (change != NULL);
-	g_return_if_fail (*change != '\0');
+	entry_text = gtk_entry_get_text (GTK_ENTRY (dlg->word_entry));
+	g_return_if_fail (entry_text != NULL);
+	g_return_if_fail (*entry_text != '\0');
+	change = g_strdup (entry_text);
 
 	pluma_spell_checker_set_correction (dlg->spell_checker, 
 					    dlg->misspelled_word, -1,
