@@ -60,11 +60,7 @@ struct _PlumaSearchDialogPrivate
 {
 	gboolean   show_replace;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkWidget *grid;
-#else
-	GtkWidget *table;
-#endif
 	GtkWidget *search_label;
 	GtkWidget *search_entry;
 	GtkWidget *search_text_entry;
@@ -72,6 +68,7 @@ struct _PlumaSearchDialogPrivate
 	GtkWidget *replace_entry;
 	GtkWidget *replace_text_entry;
 	GtkWidget *match_case_checkbutton;
+	GtkWidget *match_regex_checkbutton;
 	GtkWidget *entire_word_checkbutton;
 	GtkWidget *backwards_checkbutton;
 	GtkWidget *wrap_around_checkbutton;
@@ -301,10 +298,6 @@ show_replace_widgets (PlumaSearchDialog *dlg,
 		gtk_widget_show (dlg->priv->replace_all_button);
 		gtk_widget_show (dlg->priv->replace_button);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-		gtk_table_set_row_spacings (GTK_TABLE (dlg->priv->table), 12);
-#endif
-
 		gtk_window_set_title (GTK_WINDOW (dlg), _("Replace"));
 	}
 	else
@@ -314,10 +307,6 @@ show_replace_widgets (PlumaSearchDialog *dlg,
 		gtk_widget_hide (dlg->priv->replace_all_button);
 		gtk_widget_hide (dlg->priv->replace_button);
 
-#if !GTK_CHECK_VERSION (3, 0, 0)
-		gtk_table_set_row_spacings (GTK_TABLE (dlg->priv->table), 0);
-#endif
-
 		gtk_window_set_title (GTK_WINDOW (dlg), _("Find"));
 	}
 
@@ -354,23 +343,17 @@ pluma_search_dialog_init (PlumaSearchDialog *dlg)
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG (dlg))),
 			     6);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-	file = pluma_dirs_get_ui_file ("pluma-search-dialog-gtk3.ui");
-#else
 	file = pluma_dirs_get_ui_file ("pluma-search-dialog.ui");
-#endif
+
 	ret = pluma_utils_get_ui_objects (file,
 					  root_objects,
 					  &error_widget,
 					  "search_dialog_content", &content,
-#if GTK_CHECK_VERSION (3, 0, 0)
 					  "grid", &dlg->priv->grid,
-#else
-					  "table", &dlg->priv->table,
-#endif
 					  "search_label", &dlg->priv->search_label,
 					  "replace_with_label", &dlg->priv->replace_label,
 					  "match_case_checkbutton", &dlg->priv->match_case_checkbutton,
+					  "match_regex_checkbutton",&dlg->priv->match_regex_checkbutton,
 					  "entire_word_checkbutton", &dlg->priv->entire_word_checkbutton,
 					  "search_backwards_checkbutton", &dlg->priv->backwards_checkbutton,
 					  "wrap_around_checkbutton", &dlg->priv->wrap_around_checkbutton,
@@ -400,24 +383,16 @@ pluma_search_dialog_init (PlumaSearchDialog *dlg)
 			(PLUMA_HISTORY_ENTRY (dlg->priv->search_entry),
 			 (PlumaHistoryEntryEscapeFunc) pluma_utils_escape_search_text);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_set_hexpand (GTK_WIDGET (dlg->priv->search_entry), TRUE);
-#endif
 	dlg->priv->search_text_entry = pluma_history_entry_get_entry
 			(PLUMA_HISTORY_ENTRY (dlg->priv->search_entry));
 	gtk_entry_set_activates_default (GTK_ENTRY (dlg->priv->search_text_entry),
 					 TRUE);
 	gtk_widget_show (dlg->priv->search_entry);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_grid_attach_next_to (GTK_GRID (dlg->priv->grid),
 				 dlg->priv->search_entry,
 				 dlg->priv->search_label,
 				 GTK_POS_RIGHT, 1, 1);
-#else
-	gtk_table_attach_defaults (GTK_TABLE (dlg->priv->table),
-				   dlg->priv->search_entry,
-				   1, 2, 0, 1);
-#endif
 
 	dlg->priv->replace_entry = pluma_history_entry_new ("history-replace-with",
 							    TRUE);
@@ -425,24 +400,16 @@ pluma_search_dialog_init (PlumaSearchDialog *dlg)
 			(PLUMA_HISTORY_ENTRY (dlg->priv->replace_entry),
 			 (PlumaHistoryEntryEscapeFunc) pluma_utils_escape_search_text);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_set_hexpand (GTK_WIDGET (dlg->priv->replace_entry), TRUE);
-#endif
 	dlg->priv->replace_text_entry = pluma_history_entry_get_entry
 			(PLUMA_HISTORY_ENTRY (dlg->priv->replace_entry));
 	gtk_entry_set_activates_default (GTK_ENTRY (dlg->priv->replace_text_entry),
 					 TRUE);
 	gtk_widget_show (dlg->priv->replace_entry);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_grid_attach_next_to (GTK_GRID (dlg->priv->grid),
 				 dlg->priv->replace_entry,
 				 dlg->priv->replace_label,
 				 GTK_POS_RIGHT, 1, 1);
-#else
-	gtk_table_attach_defaults (GTK_TABLE (dlg->priv->table),
-				   dlg->priv->replace_entry,
-				   1, 2, 1, 2);
-#endif
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (dlg->priv->search_label),
 				       dlg->priv->search_entry);
@@ -617,6 +584,24 @@ pluma_search_dialog_get_match_case (PlumaSearchDialog *dialog)
 	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->match_case_checkbutton));
 }
 
+void
+pluma_search_dialog_set_match_regex (PlumaSearchDialog *dialog,
+                    gboolean           match_case)
+{
+	g_return_if_fail (PLUMA_IS_SEARCH_DIALOG (dialog));
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->match_regex_checkbutton),
+                      match_case);
+}
+
+gboolean
+pluma_search_dialog_get_match_regex (PlumaSearchDialog *dialog)
+{
+	g_return_val_if_fail (PLUMA_IS_SEARCH_DIALOG (dialog), FALSE);
+
+	return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->match_regex_checkbutton));
+}
+
 void
 pluma_search_dialog_set_entire_word (PlumaSearchDialog *dialog,
 				     gboolean           entire_word)
