@@ -39,11 +39,6 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
-#include <gtksourceview/gtksource.h>
-#else
-#include <gtksourceview/gtksourceiter.h>
-#endif
 
 #include "pluma-prefs-manager-app.h"
 #include "pluma-document.h"
@@ -178,11 +173,7 @@ enum {
 
 static guint document_signals[LAST_SIGNAL] = { 0 };
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 G_DEFINE_TYPE(PlumaDocument, pluma_document, GTK_SOURCE_TYPE_BUFFER)
-#else
-G_DEFINE_TYPE(PlumaDocument, pluma_document, GTK_TYPE_SOURCE_BUFFER)
-#endif
 
 GQuark
 pluma_document_error_quark (void)
@@ -1044,6 +1035,13 @@ set_uri (PlumaDocument *doc,
 	}
 }
 
+
+/**
+ * pluma_document_get_location:
+ * @doc: a #PlumaDocument
+ *
+ * Returns: (allow-none) (transfer full): a new #GFile
+ */
 GFile *
 pluma_document_get_location (PlumaDocument *doc)
 {
@@ -1782,7 +1780,7 @@ compute_num_of_lines (const gchar *text)
 }
 
 /**
- * pluma_document_set_search_text"
+ * pluma_document_set_search_text:
  * @doc:
  * @text: (allow-none):
  * @flags:
@@ -1881,7 +1879,7 @@ pluma_document_get_can_search_again (PlumaDocument *doc)
  * @start: (allow-none):
  * @end: (allow-none):
  * @match_start: (allow-none):
- * @match_end: (allow=none):
+ * @match_end: (allow-none):
  **/
 gboolean
 pluma_document_search_forward (PlumaDocument     *doc,
@@ -1891,11 +1889,7 @@ pluma_document_search_forward (PlumaDocument     *doc,
 			       GtkTextIter       *match_end)
 {
 	GtkTextIter iter;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkTextSearchFlags search_flags;
-#else
-	GtkSourceSearchFlags search_flags;
-#endif
 	gboolean found = FALSE;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
@@ -1919,34 +1913,33 @@ pluma_document_search_forward (PlumaDocument     *doc,
 	else
 		iter = *start;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
-#else
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
-#endif
 
 	if (!PLUMA_SEARCH_IS_CASE_SENSITIVE (doc->priv->search_flags))
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
-#else
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
-#endif
 	}
 		
 	while (!found)
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
+        	if(!PLUMA_SEARCH_IS_MATCH_REGEX(doc->priv->search_flags))
+		{
 		found = gtk_text_iter_forward_search (&iter,
-#else
-		found = gtk_source_iter_forward_search (&iter,
-#endif
-							doc->priv->search_text, 
-							search_flags,
-                        	                	&m_start, 
-                        	                	&m_end,
-                                	               	end);
-      	               	
+						      doc->priv->search_text,
+						      search_flags,
+						      &m_start,
+						      &m_end,
+						      end);
+		}else{
+		found = pluma_gtk_text_iter_regex_search (&iter,
+							  doc->priv->search_text,
+							  search_flags,
+							  &m_start,
+							  &m_end,
+							  end,
+							  TRUE);
+		}
+	
 		if (found && PLUMA_SEARCH_IS_ENTIRE_WORD (doc->priv->search_flags))
 		{
 			found = gtk_text_iter_starts_word (&m_start) && 
@@ -1974,31 +1967,27 @@ pluma_document_search_forward (PlumaDocument     *doc,
  * @start: (allow-none):
  * @end: (allow-none):
  * @match_start: (allow-none):
- * @match_end: (allow=none):
+ * @match_end: (allow-none):
  **/
 gboolean
 pluma_document_search_backward (PlumaDocument     *doc,
-				const GtkTextIter *start,
-				const GtkTextIter *end,
-				GtkTextIter       *match_start,
-				GtkTextIter       *match_end)
+                const GtkTextIter *start,
+                const GtkTextIter *end,
+                GtkTextIter       *match_start,
+                GtkTextIter       *match_end)
 {
 	GtkTextIter iter;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkTextSearchFlags search_flags;
-#else
-	GtkSourceSearchFlags search_flags;
-#endif
 	gboolean found = FALSE;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
-	
+
 	g_return_val_if_fail (PLUMA_IS_DOCUMENT (doc), FALSE);
-	g_return_val_if_fail ((start == NULL) || 
-			      (gtk_text_iter_get_buffer (start) ==  GTK_TEXT_BUFFER (doc)), FALSE);
-	g_return_val_if_fail ((end == NULL) || 
+	g_return_val_if_fail ((start == NULL) ||
+(			      gtk_text_iter_get_buffer (start) ==  GTK_TEXT_BUFFER (doc)), FALSE);
+	g_return_val_if_fail ((end == NULL) ||
 			      (gtk_text_iter_get_buffer (end) ==  GTK_TEXT_BUFFER (doc)), FALSE);
-	
+
 	if (doc->priv->search_text == NULL)
 	{
 		pluma_debug_message (DEBUG_DOCUMENT, "doc->priv->search_text == NULL\n");
@@ -2006,59 +1995,60 @@ pluma_document_search_backward (PlumaDocument     *doc,
 	}
 	else
 		pluma_debug_message (DEBUG_DOCUMENT, "doc->priv->search_text == \"%s\"\n", doc->priv->search_text);
-				      
+
 	if (end == NULL)
 		gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (doc), &iter);
 	else
 		iter = *end;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
-#else
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
-#endif
 
 	if (!PLUMA_SEARCH_IS_CASE_SENSITIVE (doc->priv->search_flags))
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
-#else
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
-#endif
 	}
 
 	while (!found)
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
-		found = gtk_text_iter_backward_search (&iter,
-#else
-		found = gtk_source_iter_backward_search (&iter,
-#endif
-							 doc->priv->search_text, 
-							 search_flags,
-                        	                	 &m_start, 
-                        	                	 &m_end,
-                                	               	 start);
-      	               	
+		if(!PLUMA_SEARCH_IS_MATCH_REGEX(doc->priv->search_flags))
+		{
+			found = gtk_text_iter_backward_search (&iter,
+							       doc->priv->search_text,
+							       search_flags,
+							       &m_start,
+							       &m_end,
+							       start);
+		}
+		else
+		{
+			found = pluma_gtk_text_iter_regex_search (&iter,
+								  doc->priv->search_text,
+								  search_flags,
+								  &m_start,
+								  &m_end,
+								  end,
+								  FALSE);
+		}
+
 		if (found && PLUMA_SEARCH_IS_ENTIRE_WORD (doc->priv->search_flags))
 		{
-			found = gtk_text_iter_starts_word (&m_start) && 
-					gtk_text_iter_ends_word (&m_end);
+			found = gtk_text_iter_starts_word (&m_start) &&
+			gtk_text_iter_ends_word (&m_end);
 
-			if (!found) 
+			if (!found)
 				iter = m_start;
 		}
 		else
 			break;
 	}
-	
+
 	if (found && (match_start != NULL))
 		*match_start = m_start;
-	
+
 	if (found && (match_end != NULL))
 		*match_end = m_end;
-	
-	return found;		      
+
+	return found;
 }
 
 /* FIXME this is an issue for introspection regardning @find */
@@ -2071,11 +2061,7 @@ pluma_document_replace_all (PlumaDocument       *doc,
 	GtkTextIter iter;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkTextSearchFlags search_flags = 0;
-#else
-	GtkSourceSearchFlags search_flags = 0;
-#endif
 	gboolean found = TRUE;
 	gint cont = 0;
 	gchar *search_text;
@@ -2100,19 +2086,11 @@ pluma_document_replace_all (PlumaDocument       *doc,
 
 	gtk_text_buffer_get_start_iter (buffer, &iter);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
-#else
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
-#endif
 
 	if (!PLUMA_SEARCH_IS_CASE_SENSITIVE (flags))
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
-#else
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
-#endif
 	}
 
 	replace_text_len = strlen (replace_text);
@@ -2135,16 +2113,23 @@ pluma_document_replace_all (PlumaDocument       *doc,
 
 	do
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
-		found = gtk_text_iter_forward_search (&iter,
-#else
-		found = gtk_source_iter_forward_search (&iter,
-#endif
-							search_text, 
-							search_flags,
-                        	                	&m_start, 
-                        	                	&m_end,
-                                	               	NULL);
+        if(!PLUMA_SEARCH_IS_MATCH_REGEX(flags))
+        {
+            found = gtk_text_iter_forward_search (&iter,
+                                                  search_text,
+                                                  search_flags,
+                                                  &m_start,
+                                                  &m_end,
+                                                  NULL);
+        }else{
+            found = pluma_gtk_text_iter_regex_search (&iter,
+                                                      search_text,
+                                                      search_flags,
+                                                      &m_start,
+                                                      &m_end,
+                                                      NULL,
+                                                      TRUE);
+        }
 
 		if (found && PLUMA_SEARCH_IS_ENTIRE_WORD (flags))
 		{
@@ -2173,7 +2158,7 @@ pluma_document_replace_all (PlumaDocument       *doc,
 						replace_text_len);
 
 			iter = m_start;
-		}		
+        }
 
 	} while (found);
 
@@ -2209,6 +2194,12 @@ pluma_document_set_language (PlumaDocument     *doc,
 	set_language (doc, lang, TRUE);
 }
 
+/**
+ * pluma_document_get_language:
+ * @doc:
+ *
+ * Return value: (transfer none):
+ */
 GtkSourceLanguage *
 pluma_document_get_language (PlumaDocument *doc)
 {
@@ -2242,15 +2233,9 @@ _pluma_document_get_seconds_since_last_save_or_load (PlumaDocument *doc)
 static void
 get_search_match_colors (PlumaDocument *doc,
 			 gboolean      *foreground_set,
-#if GTK_CHECK_VERSION (3, 14, 0)
 			 GdkRGBA       *foreground,
 			 gboolean      *background_set,
 			 GdkRGBA       *background)
-#else
-			 GdkColor      *foreground,
-			 gboolean      *background_set,
-			 GdkColor      *background)
-#endif
 {
 	GtkSourceStyleScheme *style_scheme;
 	GtkSourceStyle *style;
@@ -2275,7 +2260,6 @@ get_search_match_colors (PlumaDocument *doc,
 
 	if (*foreground_set)
 	{
-#if GTK_CHECK_VERSION (3, 14, 0)
 		if (fg == NULL ||
 		    !gdk_rgba_parse (foreground, fg))
 		{
@@ -2289,21 +2273,6 @@ get_search_match_colors (PlumaDocument *doc,
 		    !gdk_rgba_parse (background, bg))
 		{
 			*background_set = FALSE;
-#else
-		if (fg == NULL ||
-		    !gdk_color_parse (fg, foreground))
-		{
-			*foreground_set = FALSE;
-		}
-	}
-
-	if (*background_set)
-	{
-		if (bg == NULL ||
-		    !gdk_color_parse (bg, background))
-		{
-			*background_set = FALSE;
-#endif
 		}
 	}	
 
@@ -2317,11 +2286,7 @@ get_search_match_colors (PlumaDocument *doc,
 			     "Falling back to hard-coded colors "
 			     "for the \"found\" text tag.");
 
-#if GTK_CHECK_VERSION (3, 14, 0)
 	gdk_rgba_parse (background, "#FFFF78");
-#else
-	gdk_color_parse ("#FFFF78", background);
-#endif
 	*background_set = TRUE;
 	*foreground_set = FALSE;
 
@@ -2333,13 +2298,8 @@ sync_found_tag (PlumaDocument *doc,
 		GParamSpec    *pspec,
 		gpointer       data)
 {
-#if GTK_CHECK_VERSION (3, 14, 0)
 	GdkRGBA fg;
 	GdkRGBA bg;
-#else
-	GdkColor fg;
-	GdkColor bg;
-#endif
 	gboolean fg_set;
 	gboolean bg_set;
 
@@ -2352,17 +2312,10 @@ sync_found_tag (PlumaDocument *doc,
 				 &bg_set, &bg);
 
 	g_object_set (doc->priv->found_tag,
-#if GTK_CHECK_VERSION (3, 14, 0)
 		      "foreground-rgba", fg_set ? &fg : NULL,
 		      NULL);
 	g_object_set (doc->priv->found_tag,
 		      "background-rgba", bg_set ? &bg : NULL,
-#else
-		      "foreground-gdk", fg_set ? &fg : NULL,
-		      NULL);
-	g_object_set (doc->priv->found_tag,
-		      "background-gdk", bg_set ? &bg : NULL,
-#endif
 		      NULL);
 }
 
@@ -2386,11 +2339,7 @@ search_region (PlumaDocument *doc,
 	GtkTextIter iter;
 	GtkTextIter m_start;
 	GtkTextIter m_end;
-#if GTK_CHECK_VERSION (3, 0, 0)
 	GtkTextSearchFlags search_flags = 0;
-#else
-	GtkSourceSearchFlags search_flags = 0;
-#endif
 	gboolean found = TRUE;
 
 	GtkTextBuffer *buffer;	
@@ -2454,19 +2403,11 @@ search_region (PlumaDocument *doc,
 
 	iter = *start;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	search_flags = GTK_TEXT_SEARCH_VISIBLE_ONLY | GTK_TEXT_SEARCH_TEXT_ONLY;
-#else
-	search_flags = GTK_SOURCE_SEARCH_VISIBLE_ONLY | GTK_SOURCE_SEARCH_TEXT_ONLY;
-#endif
 
 	if (!PLUMA_SEARCH_IS_CASE_SENSITIVE (doc->priv->search_flags))
 	{
-#if GTK_CHECK_VERSION (3, 0, 0)
 		search_flags = search_flags | GTK_TEXT_SEARCH_CASE_INSENSITIVE;
-#else
-		search_flags = search_flags | GTK_SOURCE_SEARCH_CASE_INSENSITIVE;
-#endif
 	}
 	
 	do
@@ -2474,11 +2415,7 @@ search_region (PlumaDocument *doc,
 		if ((end != NULL) && gtk_text_iter_is_end (end))
 			end = NULL;
 			
-#if GTK_CHECK_VERSION (3, 0, 0)
 		found = gtk_text_iter_forward_search (&iter,
-#else
-		found = gtk_source_iter_forward_search (&iter,
-#endif
 							doc->priv->search_text, 
 							search_flags,
                         	                	&m_start, 
