@@ -112,10 +112,6 @@ static void pluma_prefs_manager_auto_save_changed	(GSettings *settings,
 							 gchar       *key,
 							 gpointer     user_data);
 
-static void pluma_prefs_manager_active_plugins_changed	(GSettings *settings,
-							 gchar       *key,
-							 gpointer     user_data);
-
 static void pluma_prefs_manager_lockdown_changed	(GSettings *settings,
 							 gchar       *key,
 							 gpointer     user_data);
@@ -713,11 +709,6 @@ pluma_prefs_manager_app_init (void)
 				G_CALLBACK (pluma_prefs_manager_auto_save_changed),
 				NULL);
 
-		g_signal_connect (pluma_prefs_manager->settings,
-				"changed::" GPM_ACTIVE_PLUGINS,
-				G_CALLBACK (pluma_prefs_manager_active_plugins_changed),
-				NULL);
-
 		g_signal_connect (pluma_prefs_manager->lockdown_settings,
 				"changed",
 				G_CALLBACK (pluma_prefs_manager_lockdown_changed),
@@ -1207,11 +1198,7 @@ pluma_prefs_manager_syntax_hl_enable_changed (GSettings *settings,
 
 		while (l != NULL)
 		{
-#if GTK_CHECK_VERSION (3, 0, 0)
 			g_return_if_fail (GTK_SOURCE_IS_BUFFER (l->data));
-#else
-			g_return_if_fail (GTK_IS_SOURCE_BUFFER (l->data));
-#endif
 
 			gtk_source_buffer_set_highlight_syntax (GTK_SOURCE_BUFFER (l->data),
 								enable);
@@ -1317,11 +1304,7 @@ pluma_prefs_manager_source_style_scheme_changed (GSettings *settings,
 		docs = pluma_app_get_documents (pluma_app_get_default ());
 		for (l = docs; l != NULL; l = l->next)
 		{
-#if GTK_CHECK_VERSION (3, 0, 0)
 			g_return_if_fail (GTK_SOURCE_IS_BUFFER (l->data));
-#else
-			g_return_if_fail (GTK_IS_SOURCE_BUFFER (l->data));
-#endif
 
 			gtk_source_buffer_set_style_scheme (GTK_SOURCE_BUFFER (l->data),
 							    style);
@@ -1422,23 +1405,6 @@ pluma_prefs_manager_auto_save_changed (GSettings *settings,
 	}
 }
 
-static void
-pluma_prefs_manager_active_plugins_changed (GSettings *settings,
-					    gchar       *key,
-					    gpointer     user_data)
-{
-	pluma_debug (DEBUG_PREFS);
-
-	if (strcmp (key, GPM_ACTIVE_PLUGINS) == 0)
-	{
-		PlumaPluginsEngine *engine;
-
-		engine = pluma_plugins_engine_get_default ();
-
-		pluma_plugins_engine_active_plugins_changed (engine);
-	}
-}
-
 static void
 pluma_prefs_manager_lockdown_changed (GSettings *settings,
 				      gchar       *key,
