@@ -134,11 +134,7 @@ pluma_utils_menu_position_under_widget (GtkMenu  *menu,
 	widget = GTK_WIDGET (user_data);
 	widget_get_origin (widget, x, y);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_get_preferred_size (GTK_WIDGET (menu), NULL, &requisition);
-#else
-	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
-#endif
 
 	gtk_widget_get_allocation (widget, &allocation);
 
@@ -193,11 +189,7 @@ pluma_utils_menu_position_under_tree_view (GtkMenu  *menu,
 		if (gtk_widget_get_direction (GTK_WIDGET (tree)) == GTK_TEXT_DIR_RTL)
 		{
 			GtkRequisition requisition;
-#if GTK_CHECK_VERSION (3, 0, 0)
 			gtk_widget_get_preferred_size (GTK_WIDGET (menu), NULL, &requisition);
-#else
-			gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
-#endif
 			*x += rect.width - requisition.width;
 		}
 	}
@@ -210,15 +202,13 @@ pluma_utils_menu_position_under_tree_view (GtkMenu  *menu,
 	}
 }
 
-/* FIXME: remove this with gtk 2.12, it has gdk_color_to_string */
-gchar * 
-pluma_gdk_color_to_string (GdkColor color)
-{
-	return g_strdup_printf ("#%04x%04x%04x",
-				color.red, 
-				color.green,
-				color.blue);
-}
+/**
+ * pluma_gtk_button_new_with_stock_icon:
+ * @label:
+ * @stock_id:
+ *
+ * Returns: (transfer full):
+ */
 
 GtkWidget *
 pluma_gtk_button_new_with_stock_icon (const gchar *label,
@@ -234,6 +224,15 @@ pluma_gtk_button_new_with_stock_icon (const gchar *label,
         return button;
 }
 
+/**
+ * pluma_dialog_add_button:
+ * @dialog:
+ * @text:
+ * @stock_id:
+ * @response_id:
+ *
+ * Returns: (transfer none):
+ */
 GtkWidget *
 pluma_dialog_add_button (GtkDialog   *dialog,
 			 const gchar *text,
@@ -1105,14 +1104,10 @@ handle_builder_error (const gchar *message, ...)
 	g_free (msg_plain);
 	g_free (msg);
 
-#if GTK_CHECK_VERSION (3, 14, 0)
 	gtk_widget_set_margin_start (label, 5);
 	gtk_widget_set_margin_end (label, 5);
 	gtk_widget_set_margin_top (label, 5);
 	gtk_widget_set_margin_bottom (label, 5);
-#else
-	gtk_misc_set_padding (GTK_MISC (label), 5, 5);
-#endif
 
 	return label;
 }
@@ -1395,7 +1390,7 @@ pluma_utils_uri_for_display (const gchar *uri)
  *
  * Create a list of valid uri's from a uri-list drop.
  * 
- * Return value: a string array which will hold the uris or %NULL if there
+ * Return value: (transfer full): a string array which will hold the uris or %NULL if there
  *		 were no valid uris. g_strfreev should be used when the 
  *		 string array is no longer used
  */
@@ -1583,3 +1578,130 @@ pluma_utils_decode_uri (const gchar  *uri,
 	
 	return TRUE;
 }
+
+gboolean
+pluma_gtk_text_iter_regex_search (const GtkTextIter *iter,
+				  const gchar       *str,
+				  GtkTextSearchFlags flags,
+				  GtkTextIter       *match_start,
+				  GtkTextIter       *match_end,
+				  const GtkTextIter *limit,
+				  gboolean forward_search)
+{
+	GRegex *regex;
+	GRegexCompileFlags compile_flags;
+	GMatchInfo *match_info;
+	gchar *text;
+	GtkTextIter *begin_iter;
+	GtkTextIter *end_iter;
+	gchar **all_matches;
+	gchar *match_string;
+	gboolean found;
+    gint non_null_result_number;
+    gboolean non_null_result_found;
+    guint result_size;
+	
+	compile_flags = 0;
+	if ((flags & GTK_TEXT_SEARCH_CASE_INSENSITIVE) != 0)
+        	compile_flags |= G_REGEX_CASELESS;
+
+	regex = g_regex_new (str,compile_flags,0,NULL);
+	if (regex == NULL)
+		return FALSE;
+
+    begin_iter = gtk_text_iter_copy (iter);
+	if (limit == NULL)
+	{
+        end_iter = gtk_text_iter_copy (begin_iter);
+        if (forward_search)
+		{
+        gtk_text_buffer_get_end_iter (gtk_text_iter_get_buffer(begin_iter),
+					     end_iter);
+		}
+		else
+		{
+        gtk_text_buffer_get_start_iter (gtk_text_iter_get_buffer (begin_iter),
+					       end_iter);
+		}
+	}
+	else
+	{
+        end_iter = gtk_text_iter_copy (limit);
+	}
+
+	if ((flags & GTK_TEXT_SEARCH_TEXT_ONLY) != 0)
+	{
+		if ((flags & GTK_TEXT_SEARCH_VISIBLE_ONLY) != 0)
+            text = gtk_text_iter_get_visible_text (begin_iter, end_iter);
+		else
+            text = gtk_text_iter_get_text (begin_iter, end_iter);
+	}
+	else
+	{
+		if ((flags & GTK_TEXT_SEARCH_VISIBLE_ONLY) != 0)
+            text = gtk_text_iter_get_visible_slice (begin_iter, end_iter);
+		else
+            text = gtk_text_iter_get_slice (begin_iter, end_iter);
+	}
+
+    found = g_regex_match_all (regex,text,0,&match_info);
+	if (found)
+	{
+        all_matches = g_match_info_fetch_all (match_info);
+        result_size = (gint) g_strv_length (all_matches);
+
+        if(forward_search){
+            non_null_result_number = 0;
+        } else {
+            non_null_result_number = result_size - 1 ;
+        }
+        non_null_result_found = FALSE;
+        while((non_null_result_number >= 0)
+              && (non_null_result_number < result_size) ) {
+
+            if(g_utf8_strlen (all_matches [non_null_result_number], G_MAXSSIZE) != 0) {
+                non_null_result_found = TRUE;
+                break;
+            } else {
+                if(forward_search) {
+                    non_null_result_number++;
+                } else {
+                    non_null_result_number--;
+                }
+            }
+
+        }
+
+        if(!non_null_result_found) {
+            found = FALSE;
+            goto free_resources;
+        }
+
+        match_string = all_matches [non_null_result_number];
+        if (forward_search)
+        {
+            gtk_text_iter_forward_search (begin_iter,
+						     match_string,
+						     flags,
+						     match_start,
+						     match_end,
+						     limit);
+		}
+		else
+        {
+            gtk_text_iter_backward_search (begin_iter,
+						      match_string,
+						      flags,
+						      match_start,
+						      match_end,
+						      limit);
+		}
+	}
+
+free_resources:
+    gtk_text_iter_free (begin_iter);
+    gtk_text_iter_free (end_iter);
+	g_match_info_free (match_info);
+	g_regex_unref (regex);
+	return found;
+}
